#
#	Plot human chromosome ideogram with chrM when 
#	using RCircos 1.1.2 
#
#	Last revised on November 18, 2013
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx


#	Load human chromosome ideogram data
#	which has no chrM information
#	________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

library(RCircos);
data(UCSC.HG19.Human.CytoBandIdeogram);
cyto.info <- UCSC.HG19.Human.CytoBandIdeogram;


#	Read chrM information. chrM length has
#	been scaled from 16,569 to 49,500,000
#	________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

chr.M.file <- "chrM.ideo.data.txt";
chr.M.info <- read.table(chr.M.file, header=T, 
		sep="\t", quote="")
colnames(chr.M.info) <- c("Chromosome", 
		"ChromStart", "ChromEnd", 
		"Band", "Stain");


#	Append chrM data to human chromosome 
#	ideogram data
#	________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

cyto.info <- rbind(cyto.info, chr.M.info);


#	Bypass RCircos.Set.Core.Components() 
#	to set RCircos core components
#	________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

RCircos.Initialize.Parameters(tracks.inside=5,
		tracks.outside=0);
RCircos.Set.Cytoband.data(cyto.info);
RCircos.Set.Base.Plot.Positions();


#	Plot human chromosome ideogram
#	________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

out.file <- "RCircos.Hg19withChrM.Ideogram.png";
png(out.file, height=5, width=5, unit="in", 
		res=300, type="cairo");

RCircos.Set.Plot.Area();
RCircos.Chromosome.Ideogram.Plot();
title("Human Chromosome Ideogram with ChrM");

dev.off();