#
#	Customizing chromosome band colors
#
#	Last revised on November 18, 2013
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx



#
#	Load human chromosome ideogram data
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

library(RCircos);
data(UCSC.HG19.Human.CytoBandIdeogram);
human.cyto <- UCSC.HG19.Human.CytoBandIdeogram;



#	Set up RCircos core components with chromosome
#	1, 2, and 3 only
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

chr.exclude <- paste0("chr", c(4:22, "X", "Y"))
RCircos.Set.Core.Components(cyto.info=human.cyto,
		chr.exclude, 
		tracks.inside=5, 
		tracks.outside=0);


#	Reset white bands to different colors with the
#	method of RCircos.Reset.Plot.Ideogram()
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

cyto.band <- RCircos.Get.Plot.Ideogram();

chr1.white <- cyto.band$Chromosome=="chr1" & 
	cyto.band$BandColor=="white";
cyto.band$BandColor[chr1.white==T] <- "yellow";

chr2.white <- cyto.band$Chromosome=="chr2" & 
	cyto.band$BandColor=="white";
cyto.band$BandColor[chr2.white==T] <- "magenta";

chr3.white <- cyto.band$Chromosome=="chr3" & 
	cyto.band$BandColor=="white";
cyto.band$BandColor[chr3.white==T] <- "cyan";

RCircos.Reset.Plot.Ideogram(cyto.band);


#	Plot human chromosome ideogram
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

png("RCircos.Demo.Change.Band.Color.png", height=5, 
	width=5, unit="in", type="cairo", res=300);

RCircos.Set.Plot.Area();
RCircos.Chromosome.Ideogram.Plot();

title("RCircos Demo: Change Band Color");
dev.off();

