#
#	Customizing heatmap width
#
#	Last revised on November 18, 2013
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx



#	Load human chromosome ideogram data and setup
#	RCircos core components
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

library(RCircos);
data(UCSC.HG19.Human.CytoBandIdeogram);
human.cyto <- UCSC.HG19.Human.CytoBandIdeogram;
RCircos.Set.Core.Components(cyto.info=human.cyto,
			chr.exclude=NULL, 
			tracks.inside=5, 
			tracks.outside=0);


#	Increas heatmap.width from 1000 to 10000
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

params <- RCircos.Get.Plot.Parameters()
params$heatmap.width <- 10000;
RCircos.Reset.Plot.Parameters(params)


#	Open graphci device and plot chromsome ideogram
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

out.file= "RCircos.Heatmap.Width.Demo.png";
png(file=out.file, height=5, width=5, unit="in", 
		type="cairo", res=300);

RCircos.Set.Plot.Area();
RCircos.Chromosome.Ideogram.Plot();


#	Reduce the size of heatmap data based on the
#	plot location, which is appended to the data
#	after call to RCircos.Get.Plot.Data().
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Heatmap.Data);
heatmap.data <- RCircos.Get.Plot.Data(RCircos.Heatmap.Data, 
	plot.type="plot");
selected <- round(heatmap.data$Location/10000, digits=0);
heatmap.data <- heatmap.data[duplicated(selected)==F,];


#	Plot 4 tracks heatmap data
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

side <- "in";
for(track.num in 1:4)
{
	data.col <- track.num + 4;
	RCircos.Heatmap.Plot(heatmap.data, data.col, 
		track.num, side)
}

title("RCircos.Heatmap.Width.Demo");
dev.off();

rm(list=ls(all=TRUE));


