#
#	Customize plot colors with RCircos 1.1.2 or above
#	by appending a column defining colors for each row
#	to input plot data set. The procedures works for 
#	all type plot except of heatmap plot
#
#	Last revised on November 18, 2013
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx



#	Load chromosome ideogram data and setup RCircos
#	core components
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

library(RCircos)
data(UCSC.HG19.Human.CytoBandIdeogram);
human.cyto <- UCSC.HG19.Human.CytoBandIdeogram
RCircos.Set.Core.Components(cyto.info=human.cyto, 
			chr.exclude=NULL, 
			tracks.inside=10, 
			tracks.outside=0);


#	Reset text size by modify the parameter object
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
	
params <- RCircos.Get.Plot.Parameters();
params$text.size <- 0.3;
RCircos.Reset.Plot.Parameters(params);


#	Open graphci device (here a png image file)
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

out.file <- "RCircos.Customizing.Colors.Demo.png";
png(out.file, height=5, width=5, unit="in", res=300, 
		type="cairo");


#	Plot chromosome ideogram
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

RCircos.Set.Plot.Area()
RCircos.Chromosome.Ideogram.Plot()


#	Append a column defining text colors to gene
#	data then plot connectors and gene names
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Gene.Label.Data);
gene.data <- RCircos.Gene.Label.Data;

gene.colors <- rep("black", nrow(gene.data))
gene.colors[which(gene.data$Gene=="TP53")]  <- "red";
gene.colors[which(gene.data$Gene=="BRCA2")] <- "red";
gene.colors[which(gene.data$Gene=="RB1")]   <- "red";
gene.colors[which(gene.data$Gene=="JAK1")]  <- "red";
gene.colors[which(gene.data$Gene=="JAK2")]  <- "red";
gene.colors[which(gene.data$Chromosome=="chr4")] <- "blue";
gene.data["PlotColor"] <- gene.colors;

RCircos.Gene.Connector.Plot(gene.data, track.num=1, 
			side="in");
RCircos.Gene.Name.Plot(gene.data, name.col=4, 
		track.num=2, side="in");


#	Plot heatmap with default color map. If using
#	different colors, reset heatmap.color parameter.
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Heatmap.Data);
RCircos.Heatmap.Plot(RCircos.Heatmap.Data, data.col=6, 
		track.num=5, side="in");


#	Append a column defining histogram colors to hist
#	plot data then plot histogram
#
#	hist data >0.4 will be red and others are blue
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Histogram.Data);
hist.data <- RCircos.Histogram.Data;

hist.colors <- rep("blue", nrow(hist.data))
rows <- which(hist.data$Data>0.4)
hist.colors[rows] <- "red";
hist.data["PlotColor"] <- hist.colors;

RCircos.Histogram.Plot(hist.data, data.col=4, 
	track.num=6, side="in");


#	Append a column defining line colors to line
#	plot data then plot lines
#
#	lines starting form >= 1.5 will be red and all
#	others are blue
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Line.Data);
line.data <- RCircos.Line.Data;
line.colors <- rep("blue", nrow(line.data))

rows <- which(abs(line.data$seg.mean)>=1.5);
line.colors[rows] <- "red";
line.data["PlotColor"] <- line.colors;

RCircos.Line.Plot(line.data, data.col=5, track.num=7, 
		side="in");
	

#	Append a column defining point colors to scatter
#	plot data then make scatter plot. Note: by.fold
#	must be set to 0.
#
#	Points >= 1 will be red, <=-1 will be blue, and
#	all others are yellow
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Scatter.Data);
scatter.data <- RCircos.Scatter.Data;
scatter.colors <- rep("yellow", nrow(scatter.data));
scatter.colors[which(scatter.data$seg.mean>=1)] <- "red";
scatter.colors[which(scatter.data$seg.mean<=-1)] <- "blue";

scatter.data["PlotColor"] <- scatter.colors;
RCircos.Scatter.Plot(scatter.data, data.col=5, track.num=8, 
	side="in", by.fold=0);



#	Append a column defining tile colors (rainbow)
#	to tile plot data then make tile plot
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Tile.Data);
tile.data <- RCircos.Tile.Data;
tile.data["PlotColor"] <- rep("cyan", nrow(tile.data));
RCircos.Tile.Plot(tile.data, track.num=9, side="in");


#	Append a column defining link colors (rainbow)
#	to link data and plot link lines. Note: the
#	argument of by.chromosome must be set to FALSE
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Link.Data);
link.data <- RCircos.Link.Data;
link.colors <- rainbow(nrow(link.data));
link.data["PlotColor"] <- link.colors;
RCircos.Link.Plot(link.data, track.num=11, 
		by.chromosome=FALSE);


#	Append a column defining color for ribbon link
#	then plot ribbons. Note: by.chromosome must be 
#	set to FALSE
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data(RCircos.Ribbon.Data);
ribbon.colors <- c(rgb(1, 0, 0, alpha=0.5), 
	    rgb(0, 1, 0, alpha=0.5),
	    rgb(0, 0, 1, alpha=0.5),
	    rgb(1, 1, 0, alpha=0.5));
ribbon.data <- RCircos.Ribbon.Data;
ribbon.data["PlotColor"] <- ribbon.colors;

RCircos.Ribbon.Plot(RCircos.Ribbon.Data, track.num=11, 
	by.chromosome=FALSE, twist=FALSE);


title("RCircos Plot Color Demo");

dev.off();

rm(list=ls(all=TRUE))
