#
#	Make RCircos plot with tracks using 90% track length 
#	so that labels could be added the first chromosome 
#	and the last chromosome at each track
#
#	Last revised on November 18, 2013
#	_____________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx



#	Load chromosome ideogram data and setup RCircos
#	core components
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
	
library(RCircos);
data(UCSC.HG19.Human.CytoBandIdeogram);
cyto.info <- UCSC.HG19.Human.CytoBandIdeogram;
RCircos.Set.Core.Components(cyto.info, chr.exclude=NULL, 
		tracks.inside=10, tracks.outside=0);


#	Get the three RCircos core components
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

plot.ideo <- RCircos.Get.Plot.Ideogram();
plot.pos  <- RCircos.Get.Plot.Positions();
plot.par  <- RCircos.Get.Plot.Parameters();


#	Reset text size by modifying RCircos plot 
#	parameters object
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

plot.par$text.size <- 0.3;
RCircos.Reset.Plot.Parameters(plot.par);


#	Reset plot locations of genomic position by
#	modifying RCircos ideogram object
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

empty.space <- 0.05;
scale.factor <- 1 - empty.space;
total.units <- dim(plot.pos)[1];
space.total <- round(total.units*empty.space, digits=0);
space.half <- round(space.total/2, digits=0);

new.ideogram <- plot.ideo;

unit <- new.ideogram$Unit*scale.factor;
new.ideogram$Unit <- round(unit, digits=0);

location <- new.ideogram$Location*scale.factor;
new.ideogram$Location <- round(location, digits=0);
new.ideogram$Location <- new.ideogram$Location + 
			space.half;
RCircos.Reset.Plot.Ideogram(new.ideogram);



#	Open graphic device
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

png(file="RCircos.Demo.Plot.Range.Change.png", 
		height=5, width=5, unit="in", 
		type="cairo", res=300);

RCircos.Set.Plot.Area();
title("RCircos Demo: Addjust the Plot Range");


#	Plot chromosome ideogram and all data tracks
#	_______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

RCircos.Chromosome.Ideogram.Plot();

data(RCircos.Gene.Label.Data);
RCircos.Gene.Connector.Plot(RCircos.Gene.Label.Data, 
			track.num=1, side="in");
RCircos.Gene.Name.Plot(RCircos.Gene.Label.Data, 
		name.col=4, track.num=2, side="in");

data(RCircos.Heatmap.Data);
RCircos.Heatmap.Plot(RCircos.Heatmap.Data, data.col=6, 
			track.num=5, side="in");
	
data(RCircos.Scatter.Data);
RCircos.Scatter.Plot(RCircos.Scatter.Data, data.col=5, 
		track.num=6, side="in", by.fold=1);

data(RCircos.Line.Data);
RCircos.Line.Plot(RCircos.Line.Data, data.col=5, 
			track.num=7, side="in");

data(RCircos.Histogram.Data);
RCircos.Histogram.Plot(RCircos.Histogram.Data,
		 data.col=4, track.num=8, side="in");

data(RCircos.Tile.Data);
RCircos.Tile.Plot(RCircos.Tile.Data, track.num=9, 
		side="in");
	
data(RCircos.Link.Data);
RCircos.Link.Plot(RCircos.Link.Data, track.num=11, 
			by.chromosome=FALSE);

data(RCircos.Ribbon.Data);
RCircos.Ribbon.Plot(RCircos.Ribbon.Data, track.num=11, 
		by.chromosome=FALSE, twist=FALSE);

dev.off();


rm(list=ls(all=T))

