#
#	Customizing RCircos plot to zoom in regioal area by
#	indexing and scaling RCircos plot position object
#
#	Last revised on November 18, 2013
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx


#	Load humanchromosome ideogram data and scatter
#	plot data then setup RCircos core components
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

library(RCircos);
data(UCSC.HG19.Human.CytoBandIdeogram)
data(RCircos.Scatter.Data);

human.cyto <- UCSC.HG19.Human.CytoBandIdeogram
RCircos.Set.Core.Components(cyto=human.cyto, 
			chr.exclude=NULL, 
			tracks.inside=5, 
			tracks.outside=5);


#	Open graphic device
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

png("RCircos.Demo.Zoom.Ranges.png", height=5, width=5, 
	unit="in", res=300, type="cairo");


#	Scatter plot on a track with doubled height
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

RCircos.Set.Plot.Area();
RCircos.Chromosome.Ideogram.Plot();


#	Get plot parameters and polt positions
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

positions <- RCircos.Get.Plot.Positions();
params <- RCircos.Get.Plot.Parameters();


#	Reset (double) track height and draw scatterplot
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

params$track.height <- params$track.height*2;
RCircos.Reset.Plot.Parameters(params);

RCircos.Scatter.Plot(RCircos.Scatter.Data, data.col=5, 
		track.num=1, side="in", by.fold=1);



#	Select plot area for zoom in (take 1/8 of the circle 
#	circumference in length and start at 1/16 of the 
#	circumference from 12 o'clock)
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

area.len <- round(dim(positions)[1]/8, digits=0)
area.start <- round(area.len/2, digits=0);
area.end <- area.start + area.len;

in.pos <- params$track.out.start
middle <- in.pos + params$track.height/2;
out.pos <- in.pos + params$track.height;


#	Outline the zoom area
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

polygon.x <- c(positions[area.start:area.end, 1]*out.pos,
		positions[area.end:area.start,1]*in.pos);
polygon.y<- c(positions[area.start:area.end,2]*out.pos, 
		positions[area.end:area.start,2]*in.pos);
polygon(polygon.x, polygon.y, col="aliceblue");
lines(positions[area.start:area.end,1]*middle, 
	positions[area.start:area.end,2]*middle,
	col="gray");



#	Select the chromosome 2 region to zoom in. Here
#	is the segment with more 2 fold changes. This can
#	also be done manually from file.
#	_________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

chr2.rows <- which(RCircos.Scatter.Data[,1]=="2");
chr2.data <- RCircos.Scatter.Data[chr2.rows,];
cn2.rows <- which(chr2.data[,5]>=1);

seg.start <- 122700000;
seg.end   <- 203020000;

zoom.start <- min(which(chr2.data[,2] >= seg.start));
zoom.end   <- max(which(chr2.data[,3] <= seg.end));
zoom.data <- chr2.data[zoom.start:zoom.end,];


#	Index of the plot position after zoom in
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

total.basepairs <- seg.end - seg.start +  1;
bp.per.point <- round(total.basepairs/area.len, digits=0);

zoom.pos  <- round((zoom.data[,3]-zoom.data[,2])/2, 
		digits=2) + zoom.data[,2];
zoom.pos <- round((zoom.pos-seg.start)/ bp.per.point,
		digits=0) + area.start;


#	Colored area to mark the zoom-in'ed area in the
#	scatter plot track. It covers only the top 1/4 
#	of data track so that the points in scatter plot
#	can be viewed.
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data.pos <- params$track.in.start - params$track.heigh/4;
point.one <- RCircos.Data.Point("chr2", seg.start);
point.two <- RCircos.Data.Point("chr2", seg.end);
polygon(c(positions[area.end:area.start,1]*in.pos, 
		positions[point.one:point.two, 1]*data.pos), 
	c(positions[area.end:area.start,2]*in.pos, 
		positions[point.one:point.two, 2]*data.pos), 
	col=rgb(0, 1, 1, 0.5), border=NA);



#	Plot the data point on zoom area. We alread know
#	that data values are between 1.5 and -1.5
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

data.ceiling <- 1.5;
data.col <- 5;
subtrack.height <- out.pos - middle;

for(a.point in 1:nrow(zoom.data))
{
	#	Avoid overflow
	#	_________________________________
	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

	the.data <- zoom.data[a.point, data.col];
	if(the.data > data.ceiling) { 
		the.value<- data.ceiling;
	} else if(the.data <(-1*data.ceiling)) {  
		the.value <- data.ceiling*-1;
	} else { the.value <- the.data;  }

	#	Assign color based on lo2 values
	#	_________________________________
	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

	by.fold <- 1;	
	if(the.value>=by.fold) { 
		color <- "red"; 
	} else if (the.value<=-by.fold) { 
		color <- "blue";
	} else {  color <- "black"; } 


	#	Plot the point
	#	_________________________________
	#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

	height <- middle  + 
		the.value/data.ceiling*subtrack.height;
	points(positions[zoom.pos[a.point], 1]*height,
		positions[zoom.pos[a.point], 2]*height,
		col=color, pch=19, cex=0.5);
}


#	Add ticks to zoom area (a long tick every 10MB bps)
#	by indexing RCircos.Base.Position object
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

tick.length <- 10000000;
long.width <-round(tick.length/bp.per.point, digits=0);
short.width <- round(long.width/2, digits=0);
total.long.ticks <- ceiling(area.len/long.width);
total.short.ticks <- ceiling(area.len/short.width);


#	Tick and lable posiitions. Ticks start from the
#	outboader of zoom in area
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

long.top <- out.pos + (middle-in.pos);
short.top <- long.top - (middle-in.pos)/2;

tick.start <- positions[area.start:area.end, 1:2]*out.pos;
long.tick.end <- positions[area.start:area.end, 1:2]*long.top;
short.tick.end <- positions[area.start:area.end, 1:2]*short.top;
lab.pos <- positions[area.start:area.end,]*(out.pos + params$track.height*2);
lab.pos[,3] <- positions[area.start:area.end, 3];


#	Plot ticks and labels
#	__________________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

num.long <- ceiling(seg.start/tick.length);
extra.points <- (num.long*tick.length - seg.start)/bp.per.point;
first.long <- round(extra.points, digits=0);

for(a.tick in 1:total.long.ticks)
{
	tick.pos <- first.long + (a.tick-1)*long.width;
	if(tick.pos>area.len) {break; }

	lines(c(tick.start[tick.pos,1], long.tick.end[tick.pos,1]), 
		c(tick.start[tick.pos,2], long.tick.end[tick.pos,2]),
		col="black");
	lab.text <- paste0((num.long+a.tick-1)*10, "MB");
	text(lab.pos[tick.pos,1] ,  lab.pos[tick.pos,2], 
		lab.text, srt=lab.pos[tick.pos, 3]);
}

num.short <- ceiling(seg.start/(tick.length/2));
extra.points <- (num.short*(tick.length/2) - seg.start)/bp.per.point;
first.short <- round(extra.points, digits=0);

for(a.tick in 1:total.short.ticks)
{
	tick.pos <- first.short + (a.tick-1)*long.width;
	lines(c(tick.start[tick.pos,1], long.tick.end[tick.pos,1]), 
		c(tick.start[tick.pos,2], long.tick.end[tick.pos,2]),
		col="black");
}

title("RCircos Demo: Regional Zoom")
dev.off();
