#
#	Draw chromosome ideograms with small genomes 
#	(S.Cerevisuae) by reducing base.per.unit.
#
#	Another way is to scale the genome size to
#	have enough length for viewing.
#
#	This script is based on RCircos 1.1.2. Starting
#	RCircos 1.1.3, user willn not need to bypass
#	RCircos.Set.Core.Components() function.
#
#	Last revised on November 18, 2013
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx


library(RCircos);

#	Load and select correct genomic information. 
#	There is no band information in the table and
#	each chromosome has only one entry (row).
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

ideo.table <- read.table("S.Cerevisuae.Genome.txt",
	header=F, sep="\t", quote="");
ideogram <- ideo.table[,c(2, 3, 4, 7)];

colnames(ideogram) <- c("Chromosome", "ChromStart", 
	"ChromEnd", "Band");
ideogram["Stain"] <- rep("gpos25", nrow(ideogram));


#	Manually sort the chromosome order since
#	Roman numbers are used in chromosome name
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

row.index <- c(1, 17, 5, 10, 2, 4, 9, 6, 11, 15, 3, 
	7, 12, 14, 16, 8, 13);
ideogram <- ideogram[order(row.index),];


#	Bypass the RCircos.Set.Core.Components() 
#	function to set core components
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

RCircos.Initialize.Parameters(tracks.inside=5,
			tracks.outside=0);
RCircos.Set.Cytoband.data(ideogram);
RCircos.Set.Base.Plot.Positions();


#	Reduce the base.per.unit by modifying RCircos
#	plot parameters so that one plot point will 
#	cover less base pairs of genome
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

params <- RCircos.Get.Plot.Parameters();
params$base.per.unit <- 30;
RCircos.Reset.Plot.Parameters(params);


#	Plot chromosome ideogram
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

png("S.Cerevisiae.Chromosome.Ideogram.png", width=5, 
	height=5, unit="in", res=300, type="cairo");
RCircos.Set.Plot.Area();
RCircos.Chromosome.Ideogram.Plot();
title("S.Cerevisiae Chromosome Ideogram");
dev.off();
