#
#	Working with chromosome ideogram data without
#	band information (Zebrafish).
#
#	This script is based on RCircos 1.1.2. Starting
#	RCircos 1.1.3, user willn not need to bypass
#	RCircos.Set.Core.Components() function.
#	_____________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx


#	Read in genomic data
#	_____________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

ideo.table <- read.table("Zebrafish.ideogram.txt", 
	header=F, sep="\t", quote="");
ideogram <- ideo.table[grep("chr", ideo.table[,1]),];
colnames(ideogram) <- c("Chromosome", "ChromStart", 
	"ChromEnd", "Band", "Stain");
ideogram$Band <- paste0(ideogram$Chromosome, "Band");


#	Bypass the RCircos.Set.Core.Components() 
#	function to set core components
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

RCircos.Initialize.Parameters(tracks.inside=5,
		tracks.outside=0);
RCircos.Set.Cytoband.data(ideogram);
RCircos.Set.Base.Plot.Positions();



#	Plot chromosome ideogram
#	______________________________________________
#	xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

png("Zebrafish.Chromosome.Ideogram.png", width=5, 
	height=5, unit="in", res=300, type="cairo");
RCircos.Set.Plot.Area();
RCircos.Chromosome.Ideogram.Plot();
title("Zebrafish Chromosome Ideogram");
dev.off();


